Config

Struct Config 

pub struct Config {
    pub max_typos: Option<u16>,
    pub casing: CaseMatching,
    pub unicode: UnicodeMatching,
    pub matching: Matching,
    pub sort: SortStrategy,
    pub scoring: Scoring,
}

Fields

max_typos: Option<u16>

The maximum number of characters missing from the needle, before an item in the haystack is filtered out

casing: CaseMatching

Controls how case sensitivity/insensitivity is handled while matching

unicode: UnicodeMatching

Controls how unicode is handled while matching

matching: Matching

Selects the matching algorithm: fuzzy (Smith-Waterman) or one of the literal modes (exact, prefix, suffix, substring). Literal modes require the needle to appear as a contiguous run of characters and do not support typos (max_typos is ignored).

sort: SortStrategy

Controls how results are ordered

scoring: Scoring

Controls the scoring used by the smith waterman algorithm. Pay close attention to the documentation for each property, as small changes can lead to poor matching.

Implementations

Source

impl Config

pub fn matching(self, matching: Matching) -> Self

Sets the matching mode

pub fn max_typos(self, max_typos: Option<u16>) -> Self

Sets the maximum number of typos allowed

pub fn casing(self, casing: CaseMatching) -> Self

Sets the casing mode

pub fn unicode(self, unicode: UnicodeMatching) -> Self

Sets the unicode mode

pub fn sort(self, sort: SortStrategy) -> Self

Sets how results are ordered

pub fn scoring(self, scoring: Scoring) -> Self

Sets the scoring