pub struct Config {
pub max_typos: Option<u16>,
pub sort: bool,
pub scoring: Scoring,
}Fields
max_typos: Option<u16>The maximum number of characters missing from the needle, before an item in the haystack is filtered out
sort: boolSort the results by score (descending)
scoring: ScoringControls the scoring used by the smith waterman algorithm. You may tweak these but pay close attention to the documentation for each property, as small changes can lead to poor matching.